# Output dataset

You can **drag and drop a folder** onto the input field (or copy and paste the path to the folder of interest there). The software **supports** several **formats** used in biology are supported __(*.tif, *.lsm, *.png, *.lif, *.bmp, ...)__. Upon completion of drag and drop the number of images detected in the software should be updated and the red light should disappear, if that is not the case please follow the instructions. 

**Tip:** If you are using a different **format** that is **not supported** please open the images in ImageJ/FIJI and convert the files to tif series using **File>Save As...>Image Sequence..** and then drag and drop the folder.
**Tip2:** You can also drag and drop a single file if you like

**PS:** *.jpeg files are also supported but we would not recommended using jpeg for segmentation or training as they contain compression artifacts